<?php 
/**
 *
 *  Registers various widgets for use by all child themes
 *  Enjoy!
 * 
 * @package Placester
 * @subpackage Placester
 * @since Placester 0.1
 */
 
 
if ( function_exists( 'wp_register_sidebar_widget' ) ) {
    wp_register_sidebar_widget('placester_widget_about_description', __('Placester | Footer - About Description'), 'placester_widget_about_description');
    wp_register_sidebar_widget('placester_widget_city_list', __('Placester | Footer - City/Zip/State List'), 'placester_widget_city_list');
    wp_register_sidebar_widget('placester_widget_categories', __('Placester | Footer - Categories'), 'placester_widget_categories');
    wp_register_sidebar_widget('placester_widget_contact', __('Placester | Footer - Contact Info'), 'placester_widget_contact');
    wp_register_sidebar_widget('placester_widget_ready_to_start', __('Placester | Sidebar - Ready to Get Started'), 'placester_widget_ready_to_start');
    wp_register_sidebar_widget('placester_widget_featured_properties', __('Placester | Sidebar - Featured Properties'), 'placester_widget_featured_properties');
    wp_register_sidebar_widget('placester_widget_new_properties', __('Placester | Sidebar - New Properties'), 'placester_widget_new_properties');
    wp_register_sidebar_widget('placester_widget_blog_search', __('Placester | Sidebar - Blog Search'), 'placester_widget_blog_search');
    wp_register_sidebar_widget('placester_widget_property_search', __('Placester | Sidebar - Property Search'), 'placester_widget_property_search');
    wp_register_sidebar_widget('placester_widget_share_vert', __('Placester | Sidebar - Share Vertical'), 'placester_widget_share_vert');
    wp_register_sidebar_widget('placester_widget_share_horz', __('Placester | Sidebar - Share Horizontal'), 'placester_widget_share_horz');
} 

add_action( 'widgets_init', 'register_listing_map_widget' );
function register_listing_map_widget() {
	require 'widgets/listing-map.php';
	register_widget( 'placester_widget_listing_map' );
} 

    /**
     *      Inserts an about us text into the footer
     *      using the company description.
     */
    function placester_widget_about_description ()
    {
    ?>
        <section class="links-container1">
            <section class="links-header">About</section>
            <section class="links-details">
                <p><?php echo substr(get_company_details()->description,0,220) . '...'; ?></p>
            </section>
        </section>
    <?php
    }

    /**
     *      Inserts a list of all the city, states,
     *      and zips. Designed for the footer.
     */
     function placester_widget_city_list ()
     {
         ?>
            <section class="links-container2">
                <section class="links-header">Search</section>
                <section class="links-details">
                    <div class="bycity">
                        <span>By City</span>
                        <ul>
                            <?php display_cities_footer(4) ?>

                        </ul>
                    </div>
                    <div class="byzip">
                        <span>By Zip</span>
                        <ul>
                            <?php display_zips_footer(4) ?>
                        </ul>
                    </div>
                    <div class="clr"></div>
                </section>
            </section>
         <?php
     }
     
     /**
      * Contact information widget for footer 
      */
      function placester_widget_categories ()
      {
          ?>
            <section class="links-container1">
                <section class="links-header">Categories</section>
                <section class="links-details">
                    <ul>
                        <?php  wp_list_categories(array('number' => 4, 'hierarchical' => 0, 'title_li' => '')); ?>                    
                    </ul>
                </section>
            </section>
          <?php
      }
      
      /**
       *    Contact information widget for footer
       */
       function placester_widget_contact () 
       {
           ?>
            <section class="links-container3">
                <section class="links-header">Contact</section>
                <section class="links-details2">
                    <span class="bigtxt"><?php  echo placester_get_user_details()->first_name . ' ' . placester_get_user_details()->last_name; ?></span><br/>
                    <span class="bigtxt blue"><strong><?php echo placester_get_user_details()->phone ?></strong></span><br/>
                    <span class="normaltxt"><?php echo placester_get_user_details()->email ?></span>
                </section>
            </section>
           <?php
       }
       
       /**
        *   Ready to get started widget for sidebars
        */
        function placester_widget_ready_to_start()
        {
            ?>
                <section class="side-ctnr">
                    <h3>Ready to get Started?</h3>
                    <section class="getstarted">
                        <section class="gt-thumb-size">
                            <div class="thumbs">
                                <img src="<?php echo placester_get_user_details()->logo_url ? placester_get_user_details()->logo_url : get_stylesheet_directory_uri() . '/images/gs-thumb.jpg'; ?>" alt="" />
                            </div>
                            <div class="thumbs-shadow"></div>
                        </section>
                        <section class="gs-txt">
                            <span class="bigtxt"><?php  echo placester_get_user_details()->first_name . ' ' . placester_get_user_details()->last_name; ?></span><br/>
                            <span class="bigtxt blue"><strong><?php echo substr(placester_get_user_details()->phone, 0, 11); ?></strong></span><br/>
                            <span class="normaltxt"><?php echo substr(placester_get_user_details()->email, 0, 20); ?></span>
                        </section>
                        <div class="clr"></div>
                        <div class="separator"></div>
                    </section>
                    <div class="clr"></div>
                </section>
                
            <?php
        }
        
        /**
         *      Featured Widgets for sidebars
         *      Displays properties user marked as featured
         */
         function placester_widget_featured_properties()
         {
             ?>
                <section class="side-ctnr">
                    <h3>Featured Listings</h3>
                    <ul>
                        <?php display_featured_listings(3); ?>
                    </ul>
                </section>
             <?php
         }
         
         /**
          *      Featured Widgets for sidebars
          *      Displays properties user marked as new
          */
          function placester_widget_new_properties()
          {
              ?>
                 <section class="side-ctnr">
                     <h3>New Listings</h3>
                     <ul>
                         <?php display_new_listings(3); ?>
                     </ul>
                 </section>
              <?php
          }
          
         /**
          *     Custom blog Search Widget which can be styled by the
          *     theme designer if needed
          */
          function placester_widget_blog_search ()
          {
              if (!function_exists('theme_custom_blog_search_widget')) {
                  ?>
                    <section class="side-ctnr">
                        <section class="gray-box3"><!-- search section -->
                            <form id="search-site" method="get" role="search" action="<?php echo @get_permalink(get_page_by_title('Search')->ID); ?>">
                                <span class="s1">
                                    <input type="text" class="search-input">
                                </span>
                                <span class="s2">
                                    <input type="submit" class="search-btn" value="Search">
                                </span>
                                <div class="clr"></div>
                            </form>
                        </section>
                        <div class="clr"></div>
                    </section>
                    
                  <?php
              }
          }
          
          
          /**
           *    Custom Property Widget which can be styled or customized
           *    by the theme designer if needed.
           */
           function placester_widget_property_search ()
           {
              if (!function_exists('theme_custom_blog_search_widget')) {
                   ?>
                    <section class="side-ctnr">
                        <h3>Search</h3>
                        <section id="sbar-search">
                            <div class="tbl-cell-search">
                                Bedrooms<br />
                                <div class="cselect">
                                    <select class="sparkbox-custom">
                                         <option value="1" selected="selected">1</option>
                                         <option value="2">2</option>
                                         <option value="2">3</option>
                                         <option value="2">4</option>
                                         <option value="2">5</option>
                                         <option value="2">6</option>
                                         <option value="2">7</option>
                                         <option value="2">8</option>
                                         <option value="2">9</option>
                                     </select>
                                </div>
                            </div>
                            <div class="tbl-cell-search">
                                Maximum Price
                                <div class="cselect2">
                                    <select class="sparkbox-custom">
                                        <option value="1" selected="selected">$500</option>
                                        <option value="1">$1,000</option>
                                        <option value="2">$2,000</option>
                                        <option value="2">$3,000</option>
                                        <option value="2">$4,000</option>
                                        <option value="2">$5,000</option>
                                    </select>
                                </div>
                            </div>
                            <div class="tbl-cell-search">
                                Bathrooms<br />
                                <div class="cselect">
                                    <select class="sparkbox-custom">
                                        <option value="1" selected="selected">1</option>
                                        <option value="2">2</option>
                                        <option value="2">3</option>
                                        <option value="2">4</option>
                                        <option value="2">5</option>
                                        <option value="2">6</option>
                                        <option value="2">7</option>
                                        <option value="2">8</option>
                                        <option value="2">9</option>
                                    </select>
                                </div>
                            </div>
                            <div class="tbl-cell-search">
                                Minimum Price
                                <div class="cselect2">
                                    <select class="sparkbox-custom">
                                          <option value="1" selected="selected">$200</option>
                                          <option value="1">$500</option>
                                          <option value="2">$1,000</option>
                                          <option value="2">$2,000</option>
                                          <option value="2">$3,000</option>
                                          <option value="2">$4,000</option>
                                          <option value="2">$5,000</option>
                                      </select>
                                </div>
                            </div>
                            <div class="tbl-cell-search">
                                Available
                                <div class="cselect2">
                                    <select class="sparkbox-custom">
                                        <option value="1" selected="selected">January</option>
                                        <option value="2">February</option>
                                        <option value="2">March</option>
                                        <option value="2">April</option>
                                        <option value="2">May</option>
                                        <option value="2">June</option>
                                        <option value="2">July</option>
                                        <option value="2">August</option>
                                        <option value="2">September</option>
                                        <option value="2">October</option>
                                        <option value="2">November</option>
                                        <option value="2">December</option>
                                    </select>
                                </div>
                            </div>
                            <div class="tbl-cell-search">
                                Near
                                <div class="cselect2">
                                    <select class="sparkbox-custom">
                                        <?php display_cities(); ?>
                                    </select>
                                </div>
                            </div>
                            <div class="clr"></div>
                            <div class="hr"></div>
                            <div class="clr"></div>
                                <div class="aR"><input type="submit" Value="Update Search" class="btn-sidesearch" /></div>
                                <div class="clr"></div>
                        </section>
                        <div class="separator"></div>
                    </section>
                   <?php
              }
           }
           
           /**
            *   Sharing Widgets.... Joy
            *   
            */
            function placester_widget_share_vert ()
            {
                if (!function_exists('theme_custom_ver_share_widget')) {
                    ?>
                        <section class="side-ctnr">
                            <h3>Share This</h3><!-- share this section -->
                            <section class="common-side-cont">
                                <div class="share1">
                                    <ul>
                                        <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-fb.png" alt=""/></a></li>
                                        <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-twitter.png" alt=""/></a></li>
                                        <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-digg.png" alt=""/></a></li>
                                        <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-flicker.png" alt=""/></a></li>
                                        <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-ff.png" alt=""/></a></li>
                                        <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-delcious.png" alt=""/></a></li>
                                    </ul> 
                                </div>
                                <div class="clr"></div>
                                <div class="separator"></div>
                            </section>
                            <div class="clr"></div>
                        </section>
                        
                    <?php
                }
            }
            
            /**
             *   Sharing Widgets.... Joy^2
             *   
             */
             function placester_widget_share_horz ()
             {
                 if (!function_exists('theme_custom_ver_share_widget')) {
                     ?>
                    <section class="side-ctnr">
                         <h3>Share This</h3><!-- share this section -->
                         <section class="common-side-cont">
                             <div class="share2">
                                 <ul>
                                     <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-fb.png" alt=""/></a></li>
                                     <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-twitter.png" alt=""/></a></li>
                                     <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-digg.png" alt=""/></a></li>
                                     <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-flicker.png" alt=""/></a></li>
                                     <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-ff.png" alt=""/></a></li>
                                     <li><a href="#"><img src="<?php echo get_stylesheet_directory_uri() ?>/images/social/icon-delcious.png" alt=""/></a></li>
                                 </ul> 
                             </div>
                             <div class="clr"></div>
                             <div class="separator"></div>
                         </section>
                         <div class="clr"></div>
                     </section>

                     <?php
                 }
             }
             
             
             /**
              *     Offices Widget
              */
              function placester_widget_offices ()
              {

                if (!function_exists('theme_custom_offices_widget')) {
                      ?>
                      <?php  $company_details = get_company_details(); ?>
                      <?php
                      /**
                       *     Let's display a map if the user
                       *     has a geocoded address, otherwise
                       *     we'll skip it
                       */ 
                         if (!empty($company_details->location->coords[0]) && !empty($company_details->location->coords[1])): ?>
                         <section class="side-ctnr">
                              <h3 style="margin-bottom: 3px">Offices:</h3>
                              <div style="padding: 10px">
                                  <p><?php echo $company_details->location->address; ?>, <?php echo $company_details->location->unit; ?><br />
                                  <?php echo $company_details->location->city; ?>, <?php echo $company_details->location->state; ?> <?php echo $company_details->location->zip; ?></p>
                                  <div style="height: 150px; width: 300px" id="about-map" style="float: right"></div>                                
                              </div>
                         </section>
                      <?php endif ?>
                      <?php 
                      /**
                       *      If the user's office has been geocoded,
                       *      let's give them a nice map. People like maps
                       */
                      if (!empty($company_details->location->coords[0]) && !empty($company_details->location->coords[1])): ?>

                          <?php
                          /**
                           *  Pull in google maps v3
                           *  http://code.google.com/apis/maps/documentation/javascript/
                           */
                          ?>
                          <script src="http://maps.google.com/maps/api/js?sensor=false&amp;v=3.1"></script>

                          <?php
                          /**
                           *  Simple script which creates our map, centers it on the companies location,
                           *  and puts a marker there. Most of the code is taken right from the google
                           *  maps demo. More details on google maps can be found here:
                           *  http://code.google.com/apis/maps/documentation/javascript/overlays.html#Markers
                           */
                          ?>
                          <script>
                              var latLng = new google.maps.LatLng(<?php echo $company_details->location->coords[0] ?>, <?php echo $company_details->location->coords[1] ?>);
                              window.map = new google.maps.Map(document.getElementById("about-map"),
                                {
                                  zoom: 14,
                                  center: latLng,
                              	disableDefaultUI: true,
                                  mapTypeId: google.maps.MapTypeId.ROADMAP,
                                });


                              setTimeout(function () {
                              	var marker = new google.maps.Marker({
                              		position: new google.maps.LatLng(<?php echo $company_details->location->coords[0] ?>, <?php echo $company_details->location->coords[1] ?>),
                              		map: window.map
                              	});

                              }, 500);
                          </script>
                      <?php endif ?>

                      <?php
                  }
              }
